==> Gitlab-Issue-Listing-Script-0.3.tar: Gitlab-Issue-Listing-Script-0.3/html/templates/html/issue_page.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/
defined('listpage') or die;
header('Content-Type: text/html; charset=utf-8');

?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta name="viewport" content="width=device-width, initial-scale=1">
	
	<!-- 
	
	<?php //echo GILSUtils::getAvatarUrl($issue->pkey,"xxlarge"); ?>
	
	-->
	
	<title><?php echo "{$issue['issue']['gitlab_reference']} : ".htmlentities($issue['issue']['title']); ?></title>
	<!-- <link type="application/json" href="<?php //echo qs2sef("issue={$issue->issuenum}&proj={$issue->pkey}",".json");?>" rel="alternate">
	
        <link type="text/plain" href="<?php //echo qs2sef("issue={$issue->issuenum}&proj={$issue->pkey}",".txt");?>" rel="alternate">
        -->
        
        <meta name="description" content="<?php echo "{$issue['issue']['gitlab_reference']}";?> <?php echo htmlentities($issue['issue']['description']); ?>">

        <?php 
        /*
            $keywords = explode(" ",$issue->SUMMARY);
            
            if (count(get_object_vars($labels)) > 0 ){
                foreach ($labels as $label){ 
                    $keywords[] = $label->LABEL; 
                }
            }

	    $keywords[] = "{$issue->pkey}-{$issue->issuenum}";            
	    */
        ?>
    
    <!--
	<?php //if (count($keywords) > 0 ):?>
            <meta name="keywords" content="<?php //foreach ($keywords as $label){ echo "$label,"; }?>" />	    
	<?php //endif;?>
	-->


	<script type="text/javascript">
		  function toggleStatusActivities(){
		    var entries = document.getElementsByClassName('activitystatechange');
		    for (i=0; i<entries.length;i++){
			if (entries[i].style.display != 'none'){
			    entries[i].style.display = 'none';
			}else{
			    entries[i].style.display = 'block';
			}
		    }
		  }
	</script>
	<?php require 'head-includes.php'; ?>
	</head>
	<body itemscope itemtype="http://schema.org/WebPage">

	<meta itemprop="commentCount" content="<?php echo $issue['comment_count']; ?>" />

	<hr />
	<a name="top"></a>
	
	<?php 
	// JILS-50
	//$avatar_info = getProjectAvatarURL($issue->pkey,"xxlarge");
	
	$ava = False;
	if ($issue['project']->avatar_url){
        $ava = GILSUtils::getAvatarUrl($issue['project']->avatar_url);
    }
        
	if (!$ava):?>
		<div id='logoarea'></div>
    <?php else: ?>
        <img class='projavatar-small' src='<?php echo $ava; ?>' alt="project <?php echo htmlspecialchars($issue['project']->name_with_namespace); ?> avatar">
    <?php endif; ?>
		
		<h1 itemprop="name"><?php echo "{$issue['issue']['gitlab_reference']}"; ?>: <?php echo htmlentities($issue['issue']['title']); ?></h1>
	<hr />

	<ul itemprop="breadcrumb" class="breadcrumbs">
	      
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$issue['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($issue['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("issue={$issue['issue']['gitlab_reference']}");?>"><?php echo $issue['issue']['short_reference'];?></a></li>
	      
	</ul>
	<hr />



	<a name="Info"></a>
	<h3>Issue Information</h3>

	<div class="issueInfo">
		<div class="row">
			<div class="leftcol"><b>Issue Type</b>: <?php echo $issue['issue']['type']; ?></div>
			<div class="rightcol" id="issstatus"><b>Status</b>: <span class="status<?php echo $issue['issue']["state"];?>"><?php echo $issue['issue']["state"];?></span></b></div>
		</div>
		<div class="row">
		    <div class="leftcol" id="issrptr"><b>Reported By:</b> <span itemprop="contributor" class="reporter"><?php echo GILSUtils::translateUser($issue['issue']['author']->username); ?></span></div>
		    
		    <?php if ($issue['issue']['assignee']):?>
                <div class="rightcol" id="issassignee"><b>Assigned To:</b> <span itemprop="contributor" class="assignee"><?php echo GILSUtils::translateUser($issue['issue']['assignee']->username); ?></span></div>
		    <?php endif; ?>
		</div>


		<div class="row">
                	<div class="leftcol"><br /></div>
			<div class="rightcol"></div>
		</div>


		<div class="mobilespacer">
		</div>
		<div class="row">
			
		</div>
		<div class="row">
		    <div class="leftcol" id="issproject">
			<b>Project:</b> <a itemprop="isPartOf" href="<?php echo GILSUtils::qs2sef("proj={$issue['project']->path_with_namespace}");?>"><?php echo $issue['project']->name_with_namespace; ?></a>
		    </div>
		    
		    <div class="rightcol">
                <?php if ($issue['issue']['milestone']): ?>
                <b>Milestone:</b> <a itemprop="isPartOf" href="<?php echo GILSUtils::qs2sef("milestone={$issue['issue']['milestone']->id}&projpath={$issue['project']->path_with_namespace}");?>"><?php echo $issue['issue']['milestone']->title; ?></a>
                <?php endif;?>
		    </div>
		</div>

		<div class="mobilespacer">
		</div>

		<div class="row">
        <!-- TODO: add milestone info -->
		</div>

		<div class="row">
		    <div class="leftcol" id="isslabels">
		      <?php if (count($issue['issue']['labels']) > 0 ):?>
			  <b>Labels: </b><span itemprop="keywords">
                <?php foreach ($issue['issue']['labels'] as $label): ?>
                    <span class="label"><?php echo htmlspecialchars($label); ?></span>
                <?php endforeach; ?>
		      <?php endif;?>

		    </div>
		    <div class="rightcol">
		    </div>
		</div>

		<div class="row">
			<div class="leftcol"><br /></div>
			<div class="rightcol"></div>
		</div>
		<!--sphider_noindex-->
		<div class="row">
			<div class="leftcol" id="isscreated"><b>Created</b>: <?php echo $issue['issue']['created']; ?></div>
			<div class="rightcol" id="isstimelogged">
			</div>
		</div>

		<div class="row">
			<div class="leftcol"><br /><br /></div>
			<div class="rightcol"></div>
		</div>
		<!--/sphider_noindex-->



		<div class="row">
			<div class="colspan2" id="issdescription">
				<b>Description</b><br /><div class="issuedescription"><?php echo GILSUtils::markdownToHTML($issue['issue']['description']); ?></div><br /><br />
			</div>
		</div>
		
        <div class="gitlablink">
            <a href="<?php echo GILSUtils::forceHTTPS($issue['issue']['gitlab_url']);?>">View in Gitlab</a>
        </div>		
		
	</div>
	<div style="clear: both"></div>



	<div id="commentsblock">
	<a style="float:right; font-size: 0.8em; text-decoration: none;" onclick="toggleStatusActivities(); return false;" href="#" class="toggle-state-changes">Toggle State Changes</a>
	<a name="comments"></a><h4>Activity</h4>
		
		<hr />

		<?php foreach ($issue['comments'] as $comment): ?>	
		
            <div class="activityentry activity<?php echo $comment['rowtype'];?> comment_author_<?php echo GILSUtils::translateUser($comment['author']->username); ?>"
                <?php if ($comment['rowtype'] == 'comment'): ?>
                itemscope itemtype="http://schema.org/Comment"
                <?php else: ?>
                itemscope itemtype="http://schema.org/StateChange"
                <?php endif; ?>
                >
                <a name="comment<?php echo $comment['id'];?>"></a>
                <div class="commentMetadata">
                <b itemprop="author"><?php echo GILSUtils::translateUser($comment['author']->username); ?></b>    <a itemprop="url" class="commentlink" href="#comment<?php echo $comment['id'];?>" rel="nofollow">Permalink</a><br />
                <i itemprop="dateCreated"><?php echo $comment['created']; ?></i>
                </div>
                
                <div class="<?php echo $comment['rowtype'];?>text" itemprop="text">

                    <?php echo GILSUtils::markdownToHTML($comment['body']); ?>

                </div>
                

            </div>
            
		<?php endforeach; ?>

		<div id='addComment' class='jsAddition'></div>

	</div>

</body>
</html>

==> Gitlab-Issue-Listing-Script-v0.5.tar: Gitlab-Issue-Listing-Script-v0.5/html/templates/html/issue_page.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/
defined('listpage') or die;
header('Content-Type: text/html; charset=utf-8');

?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta name="viewport" content="width=device-width, initial-scale=1">
	
	<title><?php echo $issue['issue']['short_reference'];?> <?php echo htmlentities($issue['issue']['title']) . " : {$issue['issue']['gitlab_reference']}";; ?></title>
        
        <meta name="description" content="<?php echo "{$issue['issue']['gitlab_reference']}";?> <?php echo htmlentities($issue['issue']['description']); ?>">

	<script type="text/javascript">
		  function toggleStatusActivities(){
		    var entries = document.getElementsByClassName('activitystatechange');
		    for (i=0; i<entries.length;i++){
			if (entries[i].style.display != 'none'){
			    entries[i].style.display = 'none';
			}else{
			    entries[i].style.display = 'block';
			}
		    }
		  }
	</script>
		
    <link rel="stylesheet" type="text/css" href="<?php echo GILSUtils::qs2sef("css=labels&projpath={$issue['project']->path_with_namespace}",".css");?>" />
	
	<?php require 'head-includes.php'; ?>
	</head>
	<body itemscope itemtype="http://schema.org/WebPage">

	<meta itemprop="commentCount" content="<?php echo $issue['comment_count']; ?>" />

	<hr />
	<a name="top"></a>
	
	<?php 
	$ava = False;
	if ($issue['project']->avatar_url){
        $ava = GILSUtils::getAvatarUrl($issue['project']->avatar_url);
    }
        
	if (!$ava):?>
		<div id='logoarea'></div>
    <?php else: ?>
        <img class='projavatar-small' src='<?php echo $ava; ?>' alt="project <?php echo htmlspecialchars($issue['project']->name_with_namespace); ?> avatar">
    <?php endif; ?>
		
		<h1 itemprop="name"><?php echo "{$issue['issue']['gitlab_reference']}"; ?>: <?php echo htmlentities($issue['issue']['title']); ?></h1>
	<hr />

	<ul itemprop="breadcrumb" class="breadcrumbs">
	      
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$issue['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($issue['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("issue={$issue['issue']['gitlab_reference']}");?>"><?php echo $issue['issue']['short_reference'];?></a></li>
	      
	</ul>
	<hr />



	<a name="Info"></a>
	<h3>Issue Information</h3>

	<div class="issueInfo">
		<div class="row">
			<div class="leftcol"><b>Issue Type</b>: <?php echo $issue['issue']['type']; ?></div>
			<div class="rightcol" id="issstatus"><b>Status</b>: <span class="status<?php echo $issue['issue']["state"];?>"><?php echo $issue['issue']["state"];?></span></b></div>
		</div>
		<div class="row">
		    <div class="leftcol" id="issrptr"><b>Reported By:</b> <span itemprop="contributor" class="reporter"><?php echo GILSUtils::translateUser($issue['issue']['author']->username); ?></span></div>
		    
		    <?php if ($issue['issue']['assignee']):?>
                <div class="rightcol" id="issassignee"><b>Assigned To:</b> <span itemprop="contributor" class="assignee"><?php echo GILSUtils::translateUser($issue['issue']['assignee']->username); ?></span></div>
		    <?php endif; ?>
		</div>


		<div class="row">
                	<div class="leftcol"><br /></div>
			<div class="rightcol"></div>
		</div>


		<div class="mobilespacer">
		</div>
		<div class="row">
			
		</div>
		<div class="row">
		    <div class="leftcol" id="issproject">
			<b>Project:</b> <a itemprop="isPartOf" href="<?php echo GILSUtils::qs2sef("proj={$issue['project']->path_with_namespace}");?>"><?php echo $issue['project']->name_with_namespace; ?></a>
		    </div>
		    
		    <div class="rightcol">
                <?php if ($issue['issue']['milestone']): ?>
                <b>Milestone:</b> <a itemprop="isPartOf" href="<?php echo GILSUtils::qs2sef("milestone={$issue['issue']['milestone']->id}&projpath={$issue['project']->path_with_namespace}");?>"><?php echo $issue['issue']['milestone']->title; ?></a>
                <?php endif;?>
		    </div>
		</div>

		<div class="mobilespacer">
		</div>

		<div class="row">
        <!-- TODO: add milestone info -->
		</div>

		<!--sphider_noindex-->
		<div class="row">
			<div class="leftcol" id="isscreated"><b>Created</b>: <?php echo date("d-M-y H:i",strtotime($issue['issue']['created'])); ?></div>
			<div class="rightcol" id="isstimelogged">
			</div>
		</div>

		<div class="row">
			<div class="leftcol"><br /><br /></div>
			<div class="rightcol"></div>
		</div>
		<!--/sphider_noindex-->
		
        <div style="clear: both"></div>
		<div class="row">
		    <div class="leftcol" id="isslabels">
		      <?php if (count($issue['issue']['labels']) > 0 ):?>
			  <b>Labels: </b><span itemprop="keywords">
                <?php foreach ($issue['issue']['labels'] as $label): ?>
                    <a href="<?php echo GILSUtils::qs2sef("label={$label['id']}&projpath={$issue['project']->path_with_namespace}"); ?>">

                    <span 
                       class="label labelid-<?php echo htmlspecialchars($label['id']);?>"
                       title="<?php echo htmlspecialchars($label['description']); ?>">
                        <?php echo htmlspecialchars($label['text']); ?>
                      </span>
                    </a>
                <?php endforeach; ?>
		      <?php endif;?>

		    </div>
		    <div class="rightcol">
		    </div>
		</div>
        <div style="clear: both"></div>

		<div class="row">
			<div class="leftcol"><br /></div>
			<div class="rightcol"></div>
		</div>

		<div class="row">
			<div class="colspan2" id="issdescription">
				<b>Description</b><br /><div class="issuedescription"><?php echo GILSUtils::markdownToHTML($issue['issue']['description']); ?></div><br /><br />
			</div>
		</div>
		
		<?php if ($template_vars['display_gitlab_links']): ?>
            <div class="gitlablink">
                <a href="<?php echo GILSUtils::forceHTTPS($issue['issue']['gitlab_url']);?>">View in Gitlab</a>
            </div>		
        <?php endif; ?>
		
	</div>
	<div style="clear: both"></div>

	<?php if (count($issue["related"]) > 0): ?>
    <h4>Issue Links</h4>
	<table class="related_issues">
        <?php foreach($issue["related"] as $rel): ?>
            <tr class='related_state_<?php echo $rel['state'];?>'>
                <td class="idcol"><a href="<?php echo GILSUtils::qs2sef("issue={$rel['gitlab_reference']}");?>">#<?php echo $rel['id']; ?></a></td>
                <td><?php echo htmlspecialchars($rel['title']); ?></td>
                </td>
            </tr>
        <?php endforeach; ?>
	
	</table>
	<?php endif; ?>
	

	<div id="commentsblock">
	<a style="float:right; font-size: 0.8em; text-decoration: none;" onclick="toggleStatusActivities(); return false;" href="#" class="toggle-state-changes">Toggle State Changes</a>
	<a name="comments"></a><h4>Activity</h4>
		
		<hr />

		<?php foreach ($issue['comments'] as $comment): ?>	
		   
            <div class="activityentry activity<?php echo $comment['rowtype'];?> comment_author_<?php echo GILSUtils::translateUser($comment['author']->username); ?>"
                <?php if ($comment['rowtype'] == 'comment'): ?>
                itemscope itemtype="http://schema.org/Comment"
                <?php else: ?>
                itemscope itemtype="http://schema.org/StateChange"
                <?php endif; ?>
                >
                <a name="comment<?php echo $comment['id'];?>"></a>
                <div class="commentMetadata">
                <b itemprop="author"><?php echo GILSUtils::translateUser($comment['author']->username); ?></b>    <a itemprop="url" class="commentlink" href="#comment<?php echo $comment['id'];?>" rel="nofollow">Permalink</a><br />
                <i itemprop="dateCreated"><?php echo date("d-M-y H:i", strtotime($comment['created'])); ?></i>
                </div>
                
                <div class="<?php echo $comment['rowtype'];?>text" itemprop="text">
                    <?php if ($comment['rowtype'] != "commit"): ?>
                        <?php echo GILSUtils::markdownToHTML($comment['body']); ?>
                    <?php else: ?>

                    <?php if($comment['signature']['is_signed']): ?>
                        <div class="commit_sig_status commit_sig_stat_<?php echo htmlspecialchars($comment['signature']['status']); ?>" title='Signed by "<?php echo htmlspecialchars($comment['signature']['signed_by_user']); ?>" with "<?php echo htmlspecialchars($comment['signature']['signed_by_key']); ?>"'>
                        <?php echo htmlspecialchars($comment['signature']['status']); ?> 
                        </div>
       
                    <?php endif; ?>                
                    
                    <?php echo GILSUtils::markdownToHTML($comment['body']); ?>                    
                    <div style="clear: both"></div>
<pre class="commitdetails">
Commit: <?php echo htmlspecialchars($comment['commit_ref']); ?> 
Author: <?php echo htmlspecialchars($comment['commit_author']); ?>
                            
                            
Date: <?php echo htmlspecialchars($comment['commit_date']); ?> 
</pre>
                    <br /><b>Message</b>
                    <div class="commitnotifbody">
                        <?php echo GILSUtils::markdownToHTML($comment['commit_body']); ?> </pre>
                    </div>
                    
                    <span class="additions">+<?php echo htmlspecialchars($comment['additions']); ?></span>
                    <span class="deletions">-<?php echo htmlspecialchars($comment['deletions']); ?></span>
                    <span class="total_changes">(<?php echo htmlspecialchars($comment['total_changes']); ?> lines changed)</span>
                              
                    <?php endif; ?> 
                </div>
                
            </div>
            
		<?php endforeach; ?>

		<?php if ($template_vars['display_gitlab_links']): ?>
            <div class="gitlablink">
                <a href="<?php echo GILSUtils::forceHTTPS($issue['issue']['gitlab_url']);?>">View in Gitlab</a>
            </div>		
        <?php endif; ?>		
		
		
		<div id='addComment' class='jsAddition'></div>

	</div>

</body>
</html>
